0Pricing
CUDA Academy · 강의

장치 열거 및 선택

cudaSetDevice와 GPU별 컨텍스트

장치 열거 및 선택은(는) CoddyKit의 무료 CUDA Academy 강의입니다. 이것은 4개 중 1번째 강의입니다. 아래에서 전체 강의를 무료로 읽을 수 있으며, 내장 코드 에디터와 24/7 AI 튜터와 함께 브라우저에서 직접 실습할 수 있습니다. 이 강의는 CUDA Academy 학습 경로의 일부이며, 진행 상황이 웹과 CoddyKit 앱에 동기화됩니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

이 강의의 일부는 아직 번역되지 않았으며 영어로 표시됩니다.

More Than One GPU

A single machine can hold several GPUs. To use them all, your program first needs to discover how many devices are present before it sends any work.

Counting the Devices

One call tells you how many GPUs the runtime can see. cudaGetDeviceCount writes that number into an int you hand it.

int count;
cudaGetDeviceCount(&count);

Devices Are Numbered

Each GPU gets an integer id from 0 up to count minus one. That device id is how you point the runtime at one specific card.

Picking the Active Device

You choose which GPU your next calls target with cudaSetDevice. After this, allocations and launches go to that card.

cudaSetDevice(1);

There Is a Current Device

At any moment exactly one GPU is the current device for the calling thread. Every cudaMalloc or kernel launch lands on whatever device is current.

Inspecting a Device

Before trusting a GPU you can read its specs. cudaGetDeviceProperties fills a struct with name, memory size, and compute capability.

cudaDeviceProp prop;
cudaGetDeviceProperties(&prop, 0);

Reading the Properties

The properties struct is rich. Fields like name and totalGlobalMem help you pick the best card or skip one that is too small.

Each Device Owns Its Memory

A pointer from cudaMalloc belongs to whichever GPU was current then. Using it while another device is current is an error waiting to happen.

Per-Device Contexts

Behind each GPU sits a context that holds its allocations and streams. Switching the current device switches you into that device's context.

Looping Over All GPUs

A common pattern is a loop that calls cudaSetDevice for each id, then does setup on that card. This is how you spread work across every device.

for (int d = 0; d < count; d++) {
  cudaSetDevice(d);
}

Restore Before You Leave

If a helper changes the current device, switch it back when done. Leaving the current device changed can surprise the rest of your code.

Quick Check

Recall which call chooses the GPU your next allocations and launches will use.

Recap

You count GPUs, pick one with cudaSetDevice, and inspect it with properties. Each device owns its own memory and context. Next: splitting work across them. ✨

자주 묻는 질문

“장치 열거 및 선택” 강의는 무료인가요?

네 — “장치 열거 및 선택” 전체 내용을 이 웹사이트에서 무료로 읽을 수 있습니다. 인터랙티브하게 실습하려면(내장 코드 에디터와 24/7 AI 튜터), CoddyKit PRO로 업그레이드하면 CUDA Academy 강의 전체를 잠금 해제할 수 있습니다. CUDA Academy 강의에는 총 4개의 강의가 포함되어 있습니다.

“장치 열거 및 선택”에서 뭘 배우나요?

cudaSetDevice와 GPU별 컨텍스트 브라우저에서 직접 실행하는 실습 코드로 CUDA Academy을(를) 배우며, 24/7 AI 튜터가 강의를 진행하면서 질문에 답변해줍니다.

CUDA Academy을(를) 시작하는 데 경험이 필요한가요?

사전 경험은 필요하지 않습니다. CoddyKit의 CUDA Academy은(는) 초급자부터 고급 학습자까지를 위해 구성되어 있으므로, 여기서 시작하거나 처음부터 시작할 수 있으며 자신의 속도대로 진행할 수 있습니다. 이것은 4개 중 1번째 강의입니다.

“장치 열거 및 선택” 강의는 얼마나 걸리나요?

대부분의 CoddyKit 강의는 약 5~10분이 소요됩니다. 각 강의는 간결하고 인터랙티브하여 꾸준한 진행이 가능하며, 웹과 앱에서 중단한 부분부터 바로 시작할 수 있습니다.

이 CUDA Academy 강의에서 코드를 작성하고 실행할 수 있나요?

네. 모든 CUDA Academy 강의에는 내장 코드 에디터가 포함되어 있으므로, 브라우저에서 바로 실제 코드를 작성하고 실행한 후 즉시 AI 피드백을 받을 수 있습니다 — 로컬 설정이 필요 없습니다.

이 강의의 모든 강의

  1. 장치 열거 및 선택
  2. GPU 간 작업 분할
  3. 피어 간 메모리 접근
  4. NCCL을 활용한 다중 GPU
← CUDA Academy(으)로 돌아가기